==> h5p-7.x-1.13.tar.gz: h5p/modules/h5peditor/h5peditor/language/fr.js <==
H5PEditor.language.core = {
  missingTranslation: '[Traduction manquante :key]',
  loading: 'Chargement, merci de patienter...',
  selectLibrary: 'Sélectionnez une activité pour votre exercice.',
  unknownFieldPath: 'Impossible de trouver ":path".',
  notImageField: '":path" n est pas une image.',
  notImageOrDimensionsField: '":path" n est pas une image ou aux bonnes dimensions.',
  requiredProperty: 'La :property doit être renseignée.',
  onlyNumbers: 'La :property ne peut contenir que des nombres.',
  exceedsMax: 'La :property dépasse le maximum de :max.',
  exceedsMin: 'La :property dépasse le minimum de :min.',
  outOfStep: 'La :property ne peut être effectuée que par étape  :step.',
  addFile: 'Ajouter un fichier',
  removeFile: 'Supprimer un fichier',
  confirmRemoval: 'Voulez-vous vraiment supprimer :type?',
  changeFile: 'Changer le fichier',
  semanticsError: 'Erreur de langue: :error',
  missingProperty: 'Le champ :index ne comporte pas la mention :property.',
  expandCollapse: 'Dérouler/Enrouler',
  addEntity: 'Ajouter :entity',
  tooLong: 'Ce mot est trop long, ile ne peut comporter que :max lettres ou moins.',
  invalidFormat: 'Ce champ contient un format ou un caractère invalide.',
  confirmChangeLibrary: 'Etes-vous certain de vouloir passer à une autre activité?',
  moreLibraries: 'Visitez <a href="http://h5p.org/content-types-and-applications" target="_blank"> h5p.org pour plus de contenus</a>',
  commonFields: 'Options et textes',
  commonFieldsDescription: 'Vous pouvez ici éditer les options et les textes.',
  uploading: 'Envoi en cours...',
  noFollow: 'Impossible de suivre le champ ":path".',
  editCopyright: 'Editer le copyright',
  close: 'Fermer',
  tutorialAvailable: 'Tutoriel disponible',
  editMode: 'Mode de rédaction',
  listLabel: 'Liste',
  uploadError: 'Erreur pendant l envoi du fichier',
  fileToLarge: 'Le fichier que vous envoyez est trop lourd.',
  noSemantics: 'Erreur, impossible de charger ce type de contenu.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...'
};

==> h5p-7.x-1.16.tar.gz: h5p/modules/h5peditor/h5peditor/language/fr.js <==
H5PEditor.language.core = {
  missingTranslation: '[Traduction manquante :key]',
  loading: 'Chargement, merci de patienter...',
  selectLibrary: 'Sélectionnez une activité pour votre exercice.',
  unknownFieldPath: 'Impossible de trouver ":path".',
  notImageField: '":path" n est pas une image.',
  notImageOrDimensionsField: '":path" n est pas une image ou aux bonnes dimensions.',
  requiredProperty: 'La :property doit être renseignée.',
  onlyNumbers: 'La :property ne peut contenir que des nombres.',
  exceedsMax: 'La :property dépasse le maximum de :max.',
  belowMin: 'La :property dépasse le minimum de :min.',
  outOfStep: 'La :property ne peut être effectuée que par étape  :step.',
  addFile: 'Ajouter un fichier',
  removeFile: 'Supprimer un fichier',
  confirmRemoval: 'Voulez-vous vraiment supprimer :type?',
  removeImage: 'Supprimer l\'image',
  confirmImageRemoval: 'Cela permettra d\'éliminer votre image . Êtes- vous sûr de vouloir continuer?',
  changeFile: 'Changer le fichier',
  changeLibrary: 'Changer le type de contenu',
  semanticsError: 'Erreur de langue: :error',
  missingProperty: 'Le champ :index ne comporte pas la mention :property.',
  expandCollapse: 'Dérouler/Enrouler',
  addEntity: 'Ajouter :entity',
  tooLong: 'Ce mot est trop long, ile ne peut comporter que :max lettres ou moins.',
  invalidFormat: 'Ce champ contient un format ou un caractère invalide.',
  confirmChangeLibrary: 'Etes-vous certain de vouloir passer à une autre activité?',
  moreLibraries: 'Visitez <a href="http://h5p.org/content-types-and-applications" target="_blank"> h5p.org pour plus de contenus</a>',
  commonFields: 'Options et textes',
  commonFieldsDescription: 'Vous pouvez ici éditer les options et les textes.',
  uploading: 'Envoi en cours...',
  noFollow: 'Impossible de suivre le champ ":path".',
  editCopyright: 'Editer le copyright',
  close: 'Fermer',
  tutorialAvailable: 'Tutoriel disponible',
  editMode: 'Mode de rédaction',
  listLabel: 'Liste',
  uploadError: 'Erreur pendant l envoi du fichier',
  fileToLarge: 'Le fichier que vous envoyez est trop lourd.',
  noSemantics: 'Erreur, impossible de charger ce type de contenu.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...'
};
